@@ -43,22 +43,30 @@ module TMail
               end
             end
         }
-        new( name, str, Config.to_config(conf) )
+        new(name, str, Config.to_config(conf))
+      end
+
+      def internal_new( name, conf )
+        FNAME_TO_CLASS[name].newobj('', conf, true)
       end
 
     end   # class << self
 
 
-    def initialize( body, conf )
+    def initialize( body, conf, intern = false )
       @body = body
       @config = conf
 
       @illegal = false
       @parsed = false
+      if intern
+        @parsed = true
+        parse_init
+      end
     end
 
     def inspect
-      "#<#{type} #{@body.inspect}>"
+      "#<#{self.class} #{@body.inspect}>"
     end
 
 
@@ -92,7 +100,7 @@ module TMail
 
     def body
       ensure_parsed
-      v = HFdecoder.new( s = '' )
+      v = HFdecoder.new(s = '')
       do_accept v
       v.terminate
       s
@@ -133,8 +141,11 @@ module TMail
 
     private
 
+    def parse_init
+    end
+
     def parse
-      @body = TMail::HFdecoder.decode( @body.gsub(/\n|\r\n|\r/, '') )
+      @body = TMail::HFdecoder.decode(@body.gsub(/\n|\r\n|\r/, ''))
     end
 
     def isempty?
@@ -162,15 +173,14 @@ module TMail
       save = nil
 
       begin
-        @comments = []
-        init
+        parse_init
         do_parse
       rescue SyntaxError
-        if not save and mime_encoded? @body then
+        if not save and mime_encoded? @body
           save = @body
           @body = HFdecoder.decode(save)
           retry
-        elsif save then
+        elsif save
           @body = save
         end
 
@@ -179,6 +189,11 @@ module TMail
       end
     end
 
+    def parse_init
+      @comments = []
+      init
+    end
+
     def do_parse
       obj = Parser.parse(self.class::PARSE_TYPE, @body, @comments)
       set obj if obj
@@ -250,7 +265,7 @@ module TMail
     def do_accept( strategy )
       first = true
       @addrs.each do |a|
-        if first then
+        if first
           first = false
         else
           strategy.meta ','
@@ -273,6 +288,8 @@ module TMail
 
   class ReturnPathHeader < AddressHeader
 
+    PARSE_TYPE = :RETPATH
+
     def addr
       addrs()[0]
     end
@@ -293,11 +310,12 @@ module TMail
       a = addr()
 
       strategy.meta '<'
-      unless a.routes.empty? then
-        strategy.meta a.routes.collect {|i| '@' + i }.join(',')
+      unless a.routes.empty?
+        strategy.meta a.routes.map {|i| '@' + i }.join(',')
         strategy.meta ':'
       end
-      strategy.meta a.spec
+      sp = a.spec
+      strategy.meta sp if sp
       strategy.meta '>'
     end
 
@@ -406,7 +424,7 @@ module TMail
 
     def do_parse
       str = @body
-      while m = MESSAGE_ID.match(str) do
+      while m = MESSAGE_ID.match(str)
         pre = m.pre_match.strip
         @refs.push pre unless pre.empty?
         @refs.push s = m[0]
@@ -420,7 +438,7 @@ module TMail
     def do_accept( strategy )
       first = true
       @ids.each do |i|
-        if first then
+        if first
           first = false
         else
           strategy.space
@@ -535,7 +553,7 @@ module TMail
         strategy.meta i
         first = false
       end
-      if @date then
+      if @date
         strategy.meta ';'
         strategy.space
         strategy.meta time2str(@date)
@@ -572,7 +590,7 @@ module TMail
     def do_accept( strategy )
       first = true
       @keys.each do |i|
-        if first then
+        if first
           first = false
         else
           strategy.meta ','
@@ -625,7 +643,7 @@ module TMail
     end
 
     def do_accept( strategy )
-      if @key then
+      if @key
         strategy.meta @encrypter + ','
         strategy.space
         strategy.meta @keyword
@@ -748,7 +766,7 @@ module TMail
     end
 
     def do_accept( strategy )
-      if @sub then
+      if @sub
         strategy.meta sprintf('%s/%s', @main, @sub)
       else
         strategy.meta @main
