@@ -16,13 +16,13 @@ module TMail
   class Mail
 
     def send_to( smtp )
-      do_send_to( smtp ) do
+      do_send_to(smtp) do
         ready_to_send
       end
     end
 
     def send_text_to( smtp )
-      do_send_to( smtp ) do
+      do_send_to(smtp) do
         ready_to_send
         mime_encode
       end
@@ -37,7 +37,7 @@ module TMail
     private :do_send_to
 
     def send_to_0( smtp, from, to )
-      smtp.ready( from, to ) do |f|
+      smtp.ready(from, to) do |f|
         encoded "\r\n", 'j', f, ''
       end
     end
@@ -62,7 +62,7 @@ module TMail
     end
 
     def add_message_id( fqdn = nil )
-      self.message_id = ::TMail::new_msgid( fqdn )
+      self.message_id = ::TMail::new_msgid(fqdn)
     end
 
     def add_date
@@ -70,7 +70,7 @@ module TMail
     end
 
     def mime_encode
-      if parts.empty? then
+      if parts.empty?
         mime_encode_singlepart
       else
         mime_encode_multipart true
@@ -80,7 +80,7 @@ module TMail
     def mime_encode_singlepart
       self.mime_version = '1.0'
       b = body
-      if NKF.guess(b) != NKF::BINARY then
+      if NKF.guess(b) != NKF::BINARY
         mime_encode_text b
       else
         mime_encode_binary b
@@ -103,19 +103,24 @@ module TMail
       self.mime_version = '1.0' if top
       self.set_content_type 'multipart', 'mixed'
       e = encoding(nil)
-      if e and not /\A(?:7bit|8bit|binary)\z/i === e then
+      if e and not /\A(?:7bit|8bit|binary)\z/i === e
         raise ArgumentError,
               'using C.T.Encoding with multipart mail is not permitted'
       end
     end
 
 
+    def create_empty_mail
+      self.class.new(StringPort.new(''), @config)
+    end
+
+
     def create_reply
-      setup_reply type.new( StringPort.new('') )
+      setup_reply create_empty_mail()
     end
 
     def setup_reply( m )
-      if tmp = reply_addresses(nil) then
+      if tmp = reply_addresses(nil)
         m.to_addrs = tmp
       end
 
@@ -124,22 +129,22 @@ module TMail
       tmp.push mid if mid
       m.in_reply_to = [mid] if mid
       m.references = tmp unless tmp.empty?
-      m.subject = 'Re: ' + subject('').sub( /\A(?:\s*re:)+/i, '' )
+      m.subject = 'Re: ' + subject('').sub(/\A(?:\s*re:)+/i, '')
 
       m
     end
 
 
     def create_forward
-      setup_forward type.new( StringPort.new('') )
+      setup_forward create_empty_mail()
     end
 
-    def setup_forward( m )
-      ch = TMail.new( StringPort.new('') )
-      ch.body = decoded
-      ch.set_content_type 'message', 'rfc822'
-      ch.encoding = encoding('7bit')
-      m.part.push ch
+    def setup_forward( mail )
+      m = Mail.new(StringPort.new(''))
+      m.body = decoded
+      m.set_content_type 'message', 'rfc822'
+      m.encoding = encoding('7bit')
+      mail.parts.push m
     end
   
   end
@@ -179,7 +184,7 @@ module TMail
     attr :fqdn, true
 
     def exec( mail )
-      mail.message_id = ::TMail::new_msgid( @fqdn )
+      mail.message_id = ::TMail::new_msgid(@fqdn)
     end
   
   end
@@ -218,7 +223,7 @@ module TMail
     def exec( mail )
       mail.mime_version = '1.0'
       b = mail.body
-      if NKF.guess(b) != NKF::BINARY then
+      if NKF.guess(b) != NKF::BINARY
         on_text b
       else
         on_binary b
@@ -246,7 +251,7 @@ module TMail
       mail.mime_version = '1.0' if top
       mail.set_content_type 'multipart', 'mixed'
       e = encoding(nil)
-      if e and not /\A(?:7bit|8bit|binary)\z/i === e then
+      if e and not /\A(?:7bit|8bit|binary)\z/i === e
         raise ArgumentError,
               'using C.T.Encoding with multipart mail is not permitted'
       end
