@@ -25,13 +25,9 @@ module TMail
   def self.random_tag
     @uniq += 1
     t = Time.now
-    sprintf( '%x%x_%x%x%d%x',
-             t.to_i,
-             t.tv_usec,
-             $$,
-             Thread.current.id,
-             @uniq,
-             rand(255) )
+    sprintf('%x%x_%x%x%d%x',
+            t.to_i, t.tv_usec,
+            $$, Thread.current.id, @uniq, rand(255))
   end
   private_class_method :random_tag
 
@@ -77,8 +73,8 @@ module TMail
 
 
     def join_domain( arr )
-      arr.collect {|i|
-          if /\A\[.*\]\z/ === i then
+      arr.map {|i|
+          if /\A\[.*\]\z/ === i
             i
           else
             quote_atom(i)
@@ -134,11 +130,11 @@ module TMail
     }
 
     def timezone_string_to_unixtime( str )
-      if m = /([\+\-])(\d\d?)(\d\d)/.match(str) then
+      if m = /([\+\-])(\d\d?)(\d\d)/.match(str)
         sec = (m[2].to_i * 60 + m[3].to_i) * 60
         m[1] == '-' ? -sec : sec
       else
-        min = ZONESTR_TABLE[ str.downcase ] or
+        min = ZONESTR_TABLE[str.downcase] or
                 raise SyntaxError, "wrong timezone format '#{str}'"
         min * 60
       end
@@ -153,7 +149,7 @@ module TMail
       # [ruby-list:7928]
       gmt = Time.at(tm.to_i)
       gmt.gmtime
-      offset = tm.to_i - Time.local( *gmt.to_a[0,6].reverse ).to_i
+      offset = tm.to_i - Time.local(*gmt.to_a[0,6].reverse).to_i
 
       # DO NOT USE strftime: setlocale() breaks it
       sprintf '%s, %s %s %d %02d:%02d:%02d %+.2d%.2d',
@@ -181,13 +177,13 @@ module TMail
       new = Hash.new
       encoded = nil
       hash.each do |key, value|
-        if m = /\*(?:(\d+)\*)?\z/.match(key) then
-          ((encoded ||= {})[ m.pre_match ] ||= [])[ (m[1] || 0).to_i ] = value
+        if m = /\*(?:(\d+)\*)?\z/.match(key)
+          ((encoded ||= {})[m.pre_match] ||= [])[(m[1] || 0).to_i] = value
         else
           new[key] = to_kcode(value)
         end
       end
-      if encoded then
+      if encoded
         encoded.each do |key, strings|
           new[key] = decode_RFC2231(strings.join(''))
         end
@@ -196,13 +192,13 @@ module TMail
       new
     end
 
-    FLAG = {
-      'EUC'  => '-e -m0',
-      'SJIS' => '-s -m0'
+    NKF_FLAGS = {
+      'EUC'  => '-e -m',
+      'SJIS' => '-s -m'
     }
 
     def to_kcode( str )
-      flag = FLAG[$KCODE] or return str
+      flag = NKF_FLAGS[$KCODE] or return str
       NKF.nkf(flag, str)
     end
 
@@ -210,35 +206,10 @@ module TMail
 
     def decode_RFC2231( str )
       m = RFC2231_ENCODED.match(str) or return str
-      NKF.nkf '-e', m.post_match.gsub( /%[\da-f]{2}/in ) {|s| s[1,2].hex.chr }
+      NKF.nkf(NKF_FLAGS[$KCODE],
+              m.post_match.gsub(/%[\da-f]{2}/in) {|s| s[1,2].hex.chr })
     end
-    private :decode_RFC2231
 
   end
 
-
-  #
-  # obsolete methods
-  #
-
-  extend TextUtils
-
-  class << self
-    alias msgid?    message_id?
-    alias boundary  new_boundary
-    alias msgid     new_message_id
-    alias new_msgid new_message_id
-  end
-
-  class Mail
-  end
-
-  def Mail.boundary
-    ::TMail.new_boundary
-  end
-
-  def Mail.msgid
-    ::TMail.new_message_id
-  end
-
 end
