@@ -1,5 +1,6 @@
+#!/usr/bin/ruby
 #
-# execute runit tests in T/
+# execute unit tests in T/
 #
 
 require 'runit/testsuite'
@@ -8,24 +9,15 @@ require 'runit/cui/testrunner'
 
 
 def main
-  unless File.basename(Dir.pwd) == 'T' then
-    Dir.chdir 'T'
-  end
-
-  if ARGV.empty? then
-    suite = load_all_test_cases()
-  else
-    suite = load_selected_test_cases(ARGV)
-  end
-
+  Dir.chdir 'T' unless File.basename(Dir.pwd) == 'T'
   RUNIT::CUI::TestRunner.quiet_mode = true
   writing_result {|f|
-      RUNIT::CUI::TestRunner.new(f).run suite
+      RUNIT::CUI::TestRunner.new(f).run load_test_suite(ARGV)
   }
 end
 
 def writing_result
-  if File.exist? '/dev/tty' then
+  if File.exist? '/dev/tty'
     File.open('/dev/tty', 'w') {|f|
         f.sync = true
         yield f
@@ -36,6 +28,12 @@ def writing_result
 end
 
 
+def load_test_suite( specs )
+  specs.empty?() ? load_all_test_cases() :
+                   load_selected_test_cases(specs)
+end
+
+
 def load_all_test_cases
   suite = RUNIT::TestSuite.new
   Dir.glob('test*.rb').each do |fname|
@@ -56,10 +54,8 @@ def load_selected_test_cases( specs )
 end
 
 def parse_target_spec( arg )
-  unless m = %r<\A(\w+)(?:/(\w+)(?:\.(\w+(?:,\w+)*))?)?>.match(arg) then
-    $stderr.puts "wrong arg format: #{arg}"
-    exit 1
-  end
+  m = %r<\A(\w+)(?:/(\w+)(?:\.(\w+(?:,\w+)*))?)?>.match(arg) or
+                                          fail "wrong arg format: #{arg}"
   return m[1], m[2], m[3] && m[3].split(/,/)
 end
 
@@ -67,9 +63,9 @@ def get_suite( t_file, t_class, t_methods )
   suite = RUNIT::TestSuite.new
   
   classes = load_test_classes("test#{t_file}.rb")
-  if t_class then
+  if t_class
     targclass = find_target_class(t_file, classes, t_class)
-    if t_methods then
+    if t_methods
       t_methods.each do |m|
         suite.add_test targclass.new('test_' + m)
       end
@@ -86,42 +82,48 @@ def get_suite( t_file, t_class, t_methods )
 end
 
 def find_target_class( t_file, classes, target )
-  ret = classes.find {|c|
-            c.name.split(/::/)[-1].downcase == target.downcase + 'tester'
-        }
-  unless ret then
-    $stderr.puts "no such class in test#{t_file}.rb: #{target}Tester"
-    exit 1
-  end
-  ret
+  find_target_class_0(classes, target) or
+          fail "no such class in test#{t_file}.rb: #{target}Tester"
+end
+
+def find_target_class_0( classes, target )
+  classes.find {|c|
+      c.name.split(/::/)[-1].downcase == target.downcase + 'tester'
+  }
 end
 
 
 $loaded_test_classes = []
 
 def load_test_classes( fname )
-  unless File.file? fname then
-    $stderr.puts "test script '#{fname}' not exist"
-    exit 1
-  end
+  fail "test script '#{fname}' not exist" unless File.file? fname
+
   require './' + fname
-  if $loaded_test_classes.empty? then
-    $stderr.puts "Error: #{fname} does not contains any test classes; abort."
-    exit 1
-  end
+  fail "Error: #{fname} does not contains any test classes; abort."\
+          if $loaded_test_classes.empty?
+
   ret, $loaded_test_classes = $loaded_test_classes, []
   ret
 end
 
+class Module
+  def testme!
+    fail "testme! must be called only for Class: #{self.name} is a Module"
+  end
+end
 class Class
   def testme!
-    unless RUNIT::TestCase > self then
-      $stderr.puts "class '#{self.name}' is not a RUNIT::TestCase"
-      exit 1
-    end
+    fail "class '#{self.name}' is not a RUNIT::TestCase"\
+                                    unless self < RUNIT::TestCase
     $loaded_test_classes.push self
   end
 end
 
 
+def fail( msg, status = 1 )
+  $stderr.puts msg
+  exit status
+end
+
+
 main
